Gumroad
---------

App registration (get your key and secret here)
    https://help.gumroad.com/article/280-create-application-api

Development callback URL
    http://localhost:8000/accounts/instagram/login/callback/
